syscall_entry

Function syscall_entry 

pub unsafe extern "C" fn syscall_entry() -> !
Syscall entry point

Safety

This function must never be called from rust, it should only ever be reached via the syscall instruction. Additionally, it requires that GsInfo::init and GsInfo::set_kernel_stack_top have already been called on this CPU